pub struct Locale { /* private fields */ }Expand description
Locale is a “place-holder” around what will eventually be a fluent::FluentBundle
Implementations
Sourceimpl Locale
impl Locale
Sourcepub fn new_static(id: LanguageIdentifier, str: &'static str) -> Self
pub fn new_static(id: LanguageIdentifier, str: &'static str) -> Self
Create a Locale from a static string containing Fluent (.ftl) content.
Typically used with include_str! to embed locale files at compile time.
Sourcepub fn new_dynamic(id: LanguageIdentifier, path: impl Into<PathBuf>) -> Self
pub fn new_dynamic(id: LanguageIdentifier, path: impl Into<PathBuf>) -> Self
Create a Locale from a filesystem path to a Fluent (.ftl) file.
The file will be read at runtime when the locale is loaded into a bundle.